0.2.12 (2023-04-10)
-------------------

Extended test-matrix, better `podcast_audio` field handling

* Extended the tox test-matrix to include Django 4.0
* #90 moved the `podcast_audio` field and added a warning
